==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebSortingOptionsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebSortingOptionsDescription } from "./WebSortingOptionsDescription";
/**
 * @hidden
 */
var WebSortingOptionsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebSortingOptionsDescriptionMetadata, _super);
    function WebSortingOptionsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebSortingOptionsDescriptionMetadata.b = function (a) {
        if (WebSortingOptionsDescriptionMetadata.a == null) {
            WebSortingOptionsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebSortingOptionsDescriptionMetadata.c(WebSortingOptionsDescriptionMetadata.a);
        }
        if (a.k(WebSortingOptionsDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebSortingOptionsDescriptionMetadata.a);
    };
    WebSortingOptionsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:SortingOptions");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Mode", "ExportedType:string:SortingOptionsMode");
        a.item("Mode@stringUnion", "WebComponents;React");
        a.item("Mode@names", "Single;Multiple");
    };
    WebSortingOptionsDescriptionMetadata.d = function (a) {
        WebSortingOptionsDescriptionMetadata.b(a);
        a.ac("WebSortingOptions", function () { return new WebSortingOptionsDescription(); });
        a.ab("WebSortingOptions", WebSortingOptionsDescriptionMetadata.a);
    };
    WebSortingOptionsDescriptionMetadata.$t = markType(WebSortingOptionsDescriptionMetadata, 'WebSortingOptionsDescriptionMetadata');
    WebSortingOptionsDescriptionMetadata.a = null;
    return WebSortingOptionsDescriptionMetadata;
}(Base));
export { WebSortingOptionsDescriptionMetadata };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/WebSortingOptionsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebSortingOptionsDescription } from "./WebSortingOptionsDescription";
/**
 * @hidden
 */
var WebSortingOptionsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebSortingOptionsDescriptionMetadata, _super);
    function WebSortingOptionsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebSortingOptionsDescriptionMetadata.b = function (a) {
        if (WebSortingOptionsDescriptionMetadata.a == null) {
            WebSortingOptionsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebSortingOptionsDescriptionMetadata.c(WebSortingOptionsDescriptionMetadata.a);
        }
        if (a.k(WebSortingOptionsDescriptionMetadata.a)) {
            return;
        }
        a.ac(WebSortingOptionsDescriptionMetadata.a);
    };
    WebSortingOptionsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:SortingOptions");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Mode", "ExportedType:string:SortingOptionsMode");
        a.item("Mode@stringUnion", "WebComponents;React");
        a.item("Mode@names", "Single;Multiple");
    };
    WebSortingOptionsDescriptionMetadata.d = function (a) {
        WebSortingOptionsDescriptionMetadata.b(a);
        a.ae("WebSortingOptions", function () { return new WebSortingOptionsDescription(); });
        a.ad("WebSortingOptions", WebSortingOptionsDescriptionMetadata.a);
    };
    WebSortingOptionsDescriptionMetadata.$t = markType(WebSortingOptionsDescriptionMetadata, 'WebSortingOptionsDescriptionMetadata');
    WebSortingOptionsDescriptionMetadata.a = null;
    return WebSortingOptionsDescriptionMetadata;
}(Base));
export { WebSortingOptionsDescriptionMetadata };
